@@ -41,6 +41,7 @@
 #include "accessible.h"
 #include "application.h"
 #include <bonobo-activation/bonobo-activation-register.h>
+#include <gmodule.h>
 
 #undef SPI_BRIDGE_DEBUG
 
@@ -134,7 +135,6 @@ static gint     spi_atk_bridge_key_listener            (AtkKeyEventStruct     *e
 							gpointer               data);
 static void     spi_atk_tidy_windows                   (void);
 static void     deregister_application                 (BonoboObject          *app);
-static void     reinit_register_vars                   (void);
 
 /* For automatic libgnome init */
 extern void gnome_accessibility_module_init     (void);
@@ -314,7 +314,6 @@ spi_atk_bridge_toplevel_removed (AtkObject *object,
   if (toplevels == 0)
     {
       deregister_application (app);
-      reinit_register_vars ();
     }
   if (toplevels < 0)
     {
@@ -1155,8 +1154,10 @@ spi_atk_bridge_signal_listener (GSignalInvocationHint *signal_hint,
     }
   else if ((signal_query.signal_id == atk_signal_children_changed) && gobject)
     {
+      gpointer child;
+
       detail1 = g_value_get_uint (param_values + 1);
-      gpointer child = g_value_get_pointer (param_values + 2);
+      child = g_value_get_pointer (param_values + 2);
       if (ATK_IS_OBJECT (child))
         {
           ao = ATK_OBJECT (child);
@@ -1336,14 +1337,6 @@ spi_atk_tidy_windows (void)
     }
 }
 
-static void
-reinit_register_vars (void)
-{
-  registry = CORBA_OBJECT_NIL;
-  device_event_controller = CORBA_OBJECT_NIL;
-  this_app = NULL;
-}
-
 static void
 spi_atk_bridge_init_base (CORBA_any *any, AtkObject *obj, 
 			  Accessibility_Application *app, Accessibility_Role *role,
@@ -1395,3 +1388,10 @@ spi_atk_bridge_init_rect (CORBA_any *any, AtkObject *obj, AtkRectangle *rect)
     spi_init_any_rect (any, app, role, name, rect);
 }
 
+const char *
+g_module_check_init (GModule *module)
+{
+    g_module_make_resident (module);
+
+    return NULL;
+}
