@@ -24,8 +24,10 @@
 #ifndef SPI_PRIVATE_H_
 #define SPI_PRIVATE_H_
 
-#include <glib/glist.h>
+#include <glib.h>
+#include <atk/atk.h>
 #include <orbit/orbit.h>
+#include <Accessibility.h>
 
 G_BEGIN_DECLS
 
@@ -41,13 +43,30 @@ typedef enum {
 typedef SpiReEntrantContinue (*SpiReEntrantFn) (GList * const *list,
 						gpointer       user_data);
 
+Accessibility_Role spi_role_from_atk_role (AtkRole role);
 void spi_re_entrant_list_delete_link (GList * const  *element_ptr);
 void spi_re_entrant_list_foreach     (GList         **list,
 				      SpiReEntrantFn  func,
 				      gpointer        user_data);
-void spi_init_any_nil                (CORBA_any *any);
-void spi_init_any_string             (CORBA_any *any, char **string);
-void spi_init_any_object             (CORBA_any *any, CORBA_Object *o);
+void spi_init_any_nil                (CORBA_any *any_details, 
+				      Accessibility_Application app,
+				      Accessibility_Role role,
+				      CORBA_string name);
+void spi_init_any_string             (CORBA_any *any, 
+				      Accessibility_Application app,
+				      Accessibility_Role role,
+				      CORBA_string name,
+				      char **string);
+void spi_init_any_object             (CORBA_any *any, 
+				      Accessibility_Application app,
+				      Accessibility_Role role,
+				      CORBA_string name,
+				      CORBA_Object *o);
+void spi_init_any_rect               (CORBA_any *any, 
+				      Accessibility_Application app,
+				      Accessibility_Role role,
+				      CORBA_string name,
+				      AtkRectangle *rect);
 
 G_END_DECLS
 
